using System;
using System.Xml;
using System.IO;
using System.Text;
using System.Windows.Forms;
using System.IO.Packaging;

namespace CreateWordDocFromScratch
{
  public partial class Form1 : Form
  {
    // used Namespaces
    private const string wordprocessingML = 
      @"http://schemas.openxmlformats.org/wordprocessingml/2006/main";
    
    private const string mainContentType = 
      @"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml";
    
    private const string mainRelationship = 
      @"http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument";
    
    public Form1()
    {
      InitializeComponent();
    }


    private void button1_Click(object sender, EventArgs e)
    {
       string FName = "TestDoc.docx";
       dlgFileSave.FileName = FName;
       if (dlgFileSave.ShowDialog() == DialogResult.OK)
       {
         if (!FName.EndsWith(".docx"))
           FName += ".docx";
         SaveDOCX(dlgFileSave.FileName,tbBodyText.Text);
       }
    }


    static void SaveDOCX(string fileName, string bodyText)
    {
      #region "document.xml" 
      //<w:document xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main">
      //  <w:body>
      //    <w:p>
      //      <w:r>
      //        <w:t>Beispieltext</w:t> 
      //      </w:r>
      //    </w:p>
      //  </w:body>
      //</w:document>
      #endregion

      // Create Document.xml:

      XmlDocument xdoc = new XmlDocument();
      XmlElement tagDocument = xdoc.CreateElement("w:document", wordprocessingML);
      xdoc.AppendChild(tagDocument);
      XmlElement tagBody = xdoc.CreateElement("w:body", wordprocessingML);
      tagDocument.AppendChild(tagBody);
      XmlElement tagParagraph = xdoc.CreateElement("w:p", wordprocessingML);
      tagBody.AppendChild(tagParagraph);
      XmlElement tagRun = xdoc.CreateElement("w:r", wordprocessingML);
      tagParagraph.AppendChild(tagRun);
      XmlElement tagText = xdoc.CreateElement("w:t", wordprocessingML);
      tagRun.AppendChild(tagText);
      XmlNode nodeText= xdoc.CreateNode(XmlNodeType.Text,"w:t", wordprocessingML);
      nodeText.Value = bodyText;
      tagText.AppendChild(nodeText);

      // Create Zip Package:
      using (Package zipPack = Package.Open(fileName, FileMode.Create, FileAccess.ReadWrite))
      {
        // create temp part to associate xml extenstion with type "application/xml"
        Uri uriDefaultContentType = new Uri("/default.xml", UriKind.Relative);
        PackagePart tempPart = zipPack.CreatePart(uriDefaultContentType, "application/xml");

        // save main part & content type
        Uri mainUri = new Uri("/word/document.xml", UriKind.Relative);
        PackagePart partMain = zipPack.CreatePart(mainUri, mainContentType);
        using (StreamWriter streamMainPart = new StreamWriter(partMain.GetStream(FileMode.Create, FileAccess.Write)))
        {
          xdoc.Save(streamMainPart);
        }

        // create main relationship
        zipPack.CreateRelationship(mainUri, TargetMode.Internal, mainRelationship, "rId1");
        
        // delete temp part
        zipPack.DeletePart(uriDefaultContentType);

        // save zip pack
        zipPack.Flush();

      }

      
    }

  }
}